"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// parsers/array.ts
var array_exports = {};
__export(array_exports, {
  parseArray: () => parseArray,
  parseBigintArray: () => parseBigintArray,
  parseBoolArray: () => parseBoolArray,
  parseByteAArray: () => parseByteAArray,
  parseCircleArray: () => parseCircleArray,
  parseFloatArray: () => parseFloatArray,
  parseIntArray: () => parseIntArray,
  parseIntervalArray: () => parseIntervalArray,
  parseJsonArray: () => parseJsonArray,
  parsePointArray: () => parsePointArray,
  parseTimestampArray: () => parseTimestampArray,
  parseTimestampTzArray: () => parseTimestampTzArray
});
module.exports = __toCommonJS(array_exports);
var import_basic = require("./basic.cjs");
var import_bytea = require("./bytea.cjs");
var import_geometric = require("./geometric.cjs");
var import_interval = require("./interval.cjs");
function parseArray(source, parser = import_basic.parseString) {
  return parseInternal(source, parser, false);
}
var parseBigintArray = (value) => parseArray(value, import_basic.parseBigint);
var parseBoolArray = (value) => parseArray(value, import_basic.parseBool);
var parseByteAArray = (value) => parseArray(value, import_bytea.parseByteA);
var parseCircleArray = (value) => parseArray(value, import_geometric.parseCircle);
var parseFloatArray = (value) => parseArray(value, parseFloat);
var parseIntArray = (value) => parseArray(value, parseInt);
var parseIntervalArray = (value) => parseArray(value, import_interval.parseInterval);
var parseJsonArray = (value) => parseArray(value, import_basic.parseJson);
var parsePointArray = (value) => parseArray(value, import_geometric.parsePoint);
var parseTimestampArray = (value) => parseArray(value, import_basic.parseTimestamp);
var parseTimestampTzArray = (value) => parseArray(value, import_basic.parseTimestampTz);
function parseInternal(source, parser, nested) {
  const entries = [];
  let character = "";
  let quote = false;
  let position = 0;
  let dimension = 0;
  let recorded = "";
  const newEntry = (includeEmpty) => {
    let entry = recorded;
    if (entry.length > 0 || includeEmpty) {
      if (entry === "NULL" && !includeEmpty) {
        entry = null;
      }
      if (entry !== null) {
        entries.push(parser(entry));
      } else {
        entries.push(null);
      }
      recorded = "";
    }
  };
  if (source[0] === "[") {
    while (position < source.length) {
      const char = source[position++];
      if (char === "=") {
        break;
      }
    }
  }
  while (position < source.length) {
    let escaped = false;
    character = source[position++];
    if (character === "\\") {
      character = source[position++];
      escaped = true;
    }
    if (character === "{" && !quote) {
      dimension++;
      if (dimension > 1) {
        const result = parseInternal(source.substring(position - 1), parser, true);
        entries.push(result.entries);
        position += result.position - 2;
      }
    } else if (character === "}" && !quote) {
      dimension--;
      if (!dimension) {
        newEntry();
        if (nested) {
          return {
            entries,
            position
          };
        }
      }
    } else if (character === '"' && !escaped) {
      if (quote) {
        newEntry(true);
      }
      quote = !quote;
    } else if (character === "," && !quote) {
      newEntry();
    } else {
      recorded += character;
    }
  }
  if (dimension !== 0) {
    throw new Error("array dimension not balanced");
  }
  return entries;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  parseArray,
  parseBigintArray,
  parseBoolArray,
  parseByteAArray,
  parseCircleArray,
  parseFloatArray,
  parseIntArray,
  parseIntervalArray,
  parseJsonArray,
  parsePointArray,
  parseTimestampArray,
  parseTimestampTzArray
});
//# sourceMappingURL=array.cjs.map
