import type { PGParser } from '../parsers';
import type { PGCircle, PGPoint } from './geometric';
import type { PGInterval } from './interval';
/** A parsed PostgreSQL `array` */
export type PGArray<T = string> = (T | null)[];
/** Parse a PostgreSQL array of string values */
export declare function parseArray(source: string): PGArray;
/** Parse a PostgreSQL array using the specified parser for its elements */
export declare function parseArray<T>(source: string, parser: PGParser<T>): PGArray<T>;
/** Parse a PostgreSQL array of _bigint_ values */
export declare const parseBigintArray: PGParser<PGArray<bigint>>;
/** Parse a PostgreSQL array of _boolean_ values */
export declare const parseBoolArray: PGParser<PGArray<boolean>>;
/** Parse a PostgreSQL array of _binary_ values */
export declare const parseByteAArray: PGParser<PGArray<Uint8Array>>;
/** Parse a PostgreSQL array of {@link PGCircle} values */
export declare const parseCircleArray: PGParser<PGArray<PGCircle>>;
/** Parse a PostgreSQL array of _float_ values */
export declare const parseFloatArray: PGParser<PGArray<number>>;
/** Parse a PostgreSQL array of _number_ values */
export declare const parseIntArray: PGParser<PGArray<number>>;
/** Parse a PostgreSQL array of {@link PGInterval} values */
export declare const parseIntervalArray: PGParser<PGArray<PGInterval>>;
/** Parse a PostgreSQL array of _JSON_ values */
export declare const parseJsonArray: PGParser<PGArray<any[]>>;
/** Parse a PostgreSQL array of {@link PGPoint} values */
export declare const parsePointArray: PGParser<PGArray<PGPoint>>;
/** Parse a PostgreSQL array of _timestamp without time zone_ values */
export declare const parseTimestampArray: PGParser<PGArray<Date>>;
/** Parse a PostgreSQL array of _timestamp with time zone_ values */
export declare const parseTimestampTzArray: PGParser<PGArray<Date>>;
