// parsers/array.ts
import {
  parseBigint,
  parseBool,
  parseJson,
  parseString,
  parseTimestamp,
  parseTimestampTz
} from "./basic.mjs";
import { parseByteA } from "./bytea.mjs";
import { parseCircle, parsePoint } from "./geometric.mjs";
import { parseInterval } from "./interval.mjs";
function parseArray(source, parser = parseString) {
  return parseInternal(source, parser, false);
}
var parseBigintArray = (value) => parseArray(value, parseBigint);
var parseBoolArray = (value) => parseArray(value, parseBool);
var parseByteAArray = (value) => parseArray(value, parseByteA);
var parseCircleArray = (value) => parseArray(value, parseCircle);
var parseFloatArray = (value) => parseArray(value, parseFloat);
var parseIntArray = (value) => parseArray(value, parseInt);
var parseIntervalArray = (value) => parseArray(value, parseInterval);
var parseJsonArray = (value) => parseArray(value, parseJson);
var parsePointArray = (value) => parseArray(value, parsePoint);
var parseTimestampArray = (value) => parseArray(value, parseTimestamp);
var parseTimestampTzArray = (value) => parseArray(value, parseTimestampTz);
function parseInternal(source, parser, nested) {
  const entries = [];
  let character = "";
  let quote = false;
  let position = 0;
  let dimension = 0;
  let recorded = "";
  const newEntry = (includeEmpty) => {
    let entry = recorded;
    if (entry.length > 0 || includeEmpty) {
      if (entry === "NULL" && !includeEmpty) {
        entry = null;
      }
      if (entry !== null) {
        entries.push(parser(entry));
      } else {
        entries.push(null);
      }
      recorded = "";
    }
  };
  if (source[0] === "[") {
    while (position < source.length) {
      const char = source[position++];
      if (char === "=") {
        break;
      }
    }
  }
  while (position < source.length) {
    let escaped = false;
    character = source[position++];
    if (character === "\\") {
      character = source[position++];
      escaped = true;
    }
    if (character === "{" && !quote) {
      dimension++;
      if (dimension > 1) {
        const result = parseInternal(source.substring(position - 1), parser, true);
        entries.push(result.entries);
        position += result.position - 2;
      }
    } else if (character === "}" && !quote) {
      dimension--;
      if (!dimension) {
        newEntry();
        if (nested) {
          return {
            entries,
            position
          };
        }
      }
    } else if (character === '"' && !escaped) {
      if (quote) {
        newEntry(true);
      }
      quote = !quote;
    } else if (character === "," && !quote) {
      newEntry();
    } else {
      recorded += character;
    }
  }
  if (dimension !== 0) {
    throw new Error("array dimension not balanced");
  }
  return entries;
}
export {
  parseArray,
  parseBigintArray,
  parseBoolArray,
  parseByteAArray,
  parseCircleArray,
  parseFloatArray,
  parseIntArray,
  parseIntervalArray,
  parseJsonArray,
  parsePointArray,
  parseTimestampArray,
  parseTimestampTzArray
};
//# sourceMappingURL=array.mjs.map
