// parsers/range.ts
import postgresRange from "postgres-range";
import { parseArray } from "./array.mjs";
import { parseBigint, parseString, parseTimestamp, parseTimestampTz } from "./basic.mjs";
var PGRange = class PGRangeImpl extends postgresRange.Range {
  mask;
  constructor(lower, upper, flags) {
    super(lower, upper, flags);
    this.mask = flags;
  }
  toPostgres(serialize) {
    return postgresRange.serialize(this, serialize);
  }
  static RANGE_EMPTY = postgresRange.RANGE_EMPTY;
  static RANGE_LB_INC = postgresRange.RANGE_LB_INC;
  static RANGE_UB_INC = postgresRange.RANGE_UB_INC;
  static RANGE_LB_INF = postgresRange.RANGE_LB_INF;
  static RANGE_UB_INF = postgresRange.RANGE_UB_INF;
};
function parseRange(value, parser = parseString) {
  const range = postgresRange.parse(value, parser);
  return new PGRange(range.lower, range.upper, range.mask);
}
var parseIntRange = (value) => parseRange(value, parseInt);
var parseFloatRange = (value) => parseRange(value, parseFloat);
var parseBigintRange = (value) => parseRange(value, parseBigint);
var parseTimestampRange = (value) => parseRange(value, parseTimestamp);
var parseTimestampTzRange = (value) => parseRange(value, parseTimestampTz);
var parseRangeArray = (value) => parseArray(value, parseRange);
var parseIntRangeArray = (value) => parseArray(value, parseIntRange);
var parseFloatRangeArray = (value) => parseArray(value, parseFloatRange);
var parseBigintRangeArray = (value) => parseArray(value, parseBigintRange);
var parseTimestampRangeArray = (value) => parseArray(value, parseTimestampRange);
var parseTimestampTzRangeArray = (value) => parseArray(value, parseTimestampTzRange);
export {
  PGRange,
  parseBigintRange,
  parseBigintRangeArray,
  parseFloatRange,
  parseFloatRangeArray,
  parseIntRange,
  parseIntRangeArray,
  parseRange,
  parseRangeArray,
  parseTimestampRange,
  parseTimestampRangeArray,
  parseTimestampTzRange,
  parseTimestampTzRangeArray
};
//# sourceMappingURL=range.mjs.map
