"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// registry.ts
var registry_exports = {};
__export(registry_exports, {
  Registry: () => Registry
});
module.exports = __toCommonJS(registry_exports);
var import_oids = require("./oids.cjs");
var import_parsers = require("./parsers.cjs");
var oidParsers = {
  /* Basic known types                                |_oid__|_typname______| */
  [import_oids.PGOIDs.bool]: import_parsers.parseBool,
  /*                        |   16 | bool         | */
  [import_oids.PGOIDs.bytea]: import_parsers.parseByteA,
  /*                      |   17 | bytea        | */
  [import_oids.PGOIDs.int8]: import_parsers.parseBigint,
  /*                      |   20 | int8         | */
  [import_oids.PGOIDs.int2]: parseInt,
  /*                         |   21 | int2         | */
  [import_oids.PGOIDs.int4]: parseInt,
  /*                         |   23 | int4         | */
  [import_oids.PGOIDs.oid]: parseInt,
  /*                          |   26 | oid          | */
  [import_oids.PGOIDs.json]: import_parsers.parseJson,
  /*                        |  114 | json         | */
  [import_oids.PGOIDs.point]: import_parsers.parsePoint,
  /*                      |  600 | point        | */
  [import_oids.PGOIDs.float4]: parseFloat,
  /*                     |  700 | float4       | */
  [import_oids.PGOIDs.float8]: parseFloat,
  /*                     |  701 | float8       | */
  [import_oids.PGOIDs.circle]: import_parsers.parseCircle,
  /*                    |  718 | circle       | */
  [import_oids.PGOIDs.varchar]: import_parsers.parseString,
  /*                   | 1043 | varchar      | */
  [import_oids.PGOIDs.timestamp]: import_parsers.parseTimestamp,
  /*              | 1114 | timestamp    | */
  [import_oids.PGOIDs.timestamptz]: import_parsers.parseTimestampTz,
  /*          | 1184 | timestamptz  | */
  [import_oids.PGOIDs.interval]: import_parsers.parseInterval,
  /*                | 1186 | interval     | */
  [import_oids.PGOIDs.numeric]: import_parsers.parseString,
  /*                   | 1700 | numeric      | */
  [import_oids.PGOIDs.jsonb]: import_parsers.parseJson,
  /*                       | 3802 | jsonb        | */
  /* Special types                                    |_oid__|_typname______| */
  [import_oids.PGOIDs.void]: import_parsers.parseVoid,
  /*                        | 2278 | void         | */
  [import_oids.PGOIDs.xid]: parseInt,
  /*                          |   28 | xid          | */
  [import_oids.PGOIDs.xid8]: import_parsers.parseBigint,
  /*                      | 5069 | xid8         | */
  [import_oids.PGOIDs._xid]: import_parsers.parseIntArray,
  /*                    | 1011 | _xid         | */
  [import_oids.PGOIDs._xid8]: import_parsers.parseBigintArray,
  /*                |  271 | _xid8        | */
  /* Native array types of the above                  |_oid__|_typname______| */
  [import_oids.PGOIDs._bool]: import_parsers.parseBoolArray,
  /*                  | 1000 | _bool        | */
  [import_oids.PGOIDs._bytea]: import_parsers.parseByteAArray,
  /*                | 1001 | _bytea       | */
  [import_oids.PGOIDs._int8]: import_parsers.parseBigintArray,
  /*                | 1016 | _int8        | */
  [import_oids.PGOIDs._int2]: import_parsers.parseIntArray,
  /*                   | 1005 | _int2        | */
  [import_oids.PGOIDs._int4]: import_parsers.parseIntArray,
  /*                   | 1007 | _int4        | */
  [import_oids.PGOIDs._oid]: import_parsers.parseIntArray,
  /*                    | 1028 | _oid         | */
  [import_oids.PGOIDs._json]: import_parsers.parseJsonArray,
  /*                  |  199 | _json        | */
  [import_oids.PGOIDs._point]: import_parsers.parsePointArray,
  /*                | 1017 | _point       | */
  [import_oids.PGOIDs._float4]: import_parsers.parseFloatArray,
  /*               | 1021 | _float4      | */
  [import_oids.PGOIDs._float8]: import_parsers.parseFloatArray,
  /*               | 1022 | _float8      | */
  [import_oids.PGOIDs._circle]: import_parsers.parseCircleArray,
  /*              |  719 | _circle      | */
  [import_oids.PGOIDs._timestamp]: import_parsers.parseTimestampArray,
  /*        | 1115 | _timestamp   | */
  [import_oids.PGOIDs._timestamptz]: import_parsers.parseTimestampTzArray,
  /*    | 1185 | _timestamptz | */
  [import_oids.PGOIDs._interval]: import_parsers.parseIntervalArray,
  /*          | 1187 | _interval    | */
  [import_oids.PGOIDs._numeric]: import_parsers.parseArray,
  /*                   | 1231 | _numeric     | */
  [import_oids.PGOIDs._jsonb]: import_parsers.parseJsonArray,
  /*                 | 3807 | _jsonb       | */
  /* Other known array types                          |_oid__|_typname______| */
  [import_oids.PGOIDs._cidr]: import_parsers.parseArray,
  /*                      |  651 | _cidr        | */
  [import_oids.PGOIDs._money]: import_parsers.parseArray,
  /*                     |  791 | _money       | */
  [import_oids.PGOIDs._regproc]: import_parsers.parseArray,
  /*                   | 1008 | _regproc     | */
  [import_oids.PGOIDs._text]: import_parsers.parseArray,
  /*                      | 1009 | _text        | */
  [import_oids.PGOIDs._bpchar]: import_parsers.parseArray,
  /*                    | 1014 | _bpchar      | */
  [import_oids.PGOIDs._varchar]: import_parsers.parseArray,
  /*                   | 1015 | _varchar     | */
  [import_oids.PGOIDs._macaddr]: import_parsers.parseArray,
  /*                   | 1040 | _macaddr     | */
  [import_oids.PGOIDs._inet]: import_parsers.parseArray,
  /*                      | 1041 | _inet        | */
  [import_oids.PGOIDs._date]: import_parsers.parseArray,
  /*                      | 1182 | _date        | */
  [import_oids.PGOIDs._time]: import_parsers.parseArray,
  /*                      | 1183 | _time        | */
  [import_oids.PGOIDs._timetz]: import_parsers.parseArray,
  /*                    | 1270 | _timetz      | */
  [import_oids.PGOIDs._uuid]: import_parsers.parseArray,
  /*                      | 2951 | _uuid        | */
  /* Range types                                      |_oid__|_typname______| */
  [import_oids.PGOIDs.int4range]: import_parsers.parseIntRange,
  /*               | 3904 | int4range    | */
  [import_oids.PGOIDs.numrange]: import_parsers.parseFloatRange,
  /*              | 3906 | numrange     | */
  [import_oids.PGOIDs.tsrange]: import_parsers.parseTimestampRange,
  /*           | 3908 | tsrange      | */
  [import_oids.PGOIDs.tstzrange]: import_parsers.parseTimestampTzRange,
  /*       | 3910 | tstzrange    | */
  [import_oids.PGOIDs.daterange]: import_parsers.parseRange,
  /*                  | 3912 | daterange    | */
  [import_oids.PGOIDs.int8range]: import_parsers.parseBigintRange,
  /*            | 3926 | int8range    | */
  /* Array of range types                             |_oid__|_typname______| */
  [import_oids.PGOIDs._int4range]: import_parsers.parseIntRangeArray,
  /*         | 3905 | _int4range   | */
  [import_oids.PGOIDs._numrange]: import_parsers.parseFloatRangeArray,
  /*        | 3907 | _numrange    | */
  [import_oids.PGOIDs._tsrange]: import_parsers.parseTimestampRangeArray,
  /*     | 3909 | _tsrange     | */
  [import_oids.PGOIDs._tstzrange]: import_parsers.parseTimestampTzRangeArray,
  /* | 3911 | _tstzrange   | */
  [import_oids.PGOIDs._daterange]: import_parsers.parseRangeArray,
  /*            | 3913 | _daterange   | */
  [import_oids.PGOIDs._int8range]: import_parsers.parseBigintRangeArray
  /*      | 3927 | _int8range   | */
};
var defaultParsers = { ...oidParsers };
var RegistryImpl = class {
  _parsers;
  constructor() {
    this._parsers = { ...oidParsers };
  }
  deregisterParser(oid) {
    delete this._parsers[oid];
    return this;
  }
  registerParser(oid, parser) {
    this._parsers[oid] = parser;
    return this;
  }
  getParser(oid) {
    return this._parsers[oid] || defaultParsers[oid] || import_parsers.parseString;
  }
  static deregisterDefaultParser(oid) {
    delete defaultParsers[oid];
  }
  static registerDefaultParser(oid, parser) {
    defaultParsers[oid] = parser;
  }
};
var Registry = RegistryImpl;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Registry
});
//# sourceMappingURL=registry.cjs.map
