import { parseArray, parseByteA, parseRange } from './parsers';
import type { PGParser } from './parsers';
export interface Registry {
    deregisterParser(oid: number): this;
    registerParser(oid: number, parser: PGParser<any>): this;
    getParser(oid: number): PGParser<any>;
}
declare const oidParsers: {
    16: PGParser<boolean>;
    17: typeof parseByteA;
    20: PGParser<bigint>;
    21: typeof parseInt;
    23: typeof parseInt;
    26: typeof parseInt;
    114: PGParser<any>;
    600: PGParser<import(".").PGPoint>;
    700: typeof parseFloat;
    701: typeof parseFloat;
    718: PGParser<import(".").PGCircle>;
    1043: PGParser<string>;
    1114: PGParser<Date>;
    1184: PGParser<Date>;
    1186: PGParser<import(".").PGInterval>;
    1700: PGParser<string>;
    3802: PGParser<any>;
    2278: PGParser<null>;
    28: typeof parseInt;
    5069: PGParser<bigint>;
    1011: PGParser<import(".").PGArray<number>>;
    271: PGParser<import(".").PGArray<bigint>>;
    1000: PGParser<import(".").PGArray<boolean>>;
    1001: PGParser<import(".").PGArray<Uint8Array>>;
    1016: PGParser<import(".").PGArray<bigint>>;
    1005: PGParser<import(".").PGArray<number>>;
    1007: PGParser<import(".").PGArray<number>>;
    1028: PGParser<import(".").PGArray<number>>;
    199: PGParser<import(".").PGArray<any[]>>;
    1017: PGParser<import(".").PGArray<import(".").PGPoint>>;
    1021: PGParser<import(".").PGArray<number>>;
    1022: PGParser<import(".").PGArray<number>>;
    719: PGParser<import(".").PGArray<import(".").PGCircle>>;
    1115: PGParser<import(".").PGArray<Date>>;
    1185: PGParser<import(".").PGArray<Date>>;
    1187: PGParser<import(".").PGArray<import(".").PGInterval>>;
    1231: typeof parseArray;
    3807: PGParser<import(".").PGArray<any[]>>;
    651: typeof parseArray;
    791: typeof parseArray;
    1008: typeof parseArray;
    1009: typeof parseArray;
    1014: typeof parseArray;
    1015: typeof parseArray;
    1040: typeof parseArray;
    1041: typeof parseArray;
    1182: typeof parseArray;
    1183: typeof parseArray;
    1270: typeof parseArray;
    2951: typeof parseArray;
    3904: PGParser<import(".").PGRange<number>>;
    3906: PGParser<import(".").PGRange<number>>;
    3908: PGParser<import(".").PGRange<Date>>;
    3910: PGParser<import(".").PGRange<Date>>;
    3912: typeof parseRange;
    3926: PGParser<import(".").PGRange<bigint>>;
    3905: PGParser<import(".").PGArray<import(".").PGRange<number>>>;
    3907: PGParser<import(".").PGArray<import(".").PGRange<number>>>;
    3909: PGParser<import(".").PGArray<import(".").PGRange<Date>>>;
    3911: PGParser<import(".").PGArray<import(".").PGRange<Date>>>;
    3913: PGParser<import(".").PGArray<import(".").PGRange<string>>>;
    3927: PGParser<import(".").PGArray<import(".").PGRange<bigint>>>;
};
export type RegistryTypes = {
    [key in keyof typeof oidParsers]: typeof oidParsers[key] extends PGParser<infer T> ? T : never;
};
export interface RegistryConstructor {
    new (): Registry;
    deregisterDefaultParser(oid: number): void;
    registerDefaultParser(oid: number, parser: PGParser<any>): void;
}
export declare const Registry: RegistryConstructor;
export {};
