"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// serializers.ts
var serializers_exports = {};
__export(serializers_exports, {
  serialize: () => serialize,
  serializeByteA: () => import_bytea2.serializeByteA,
  serializeDateUTC: () => import_date2.serializeDateUTC
});
module.exports = __toCommonJS(serializers_exports);
var import_bytea = require("./serializers/bytea.cjs");
var import_date = require("./serializers/date.cjs");
var import_bytea2 = require("./serializers/bytea.cjs");
var import_date2 = require("./serializers/date.cjs");
var serializationCache = /* @__PURE__ */ new WeakMap();
function quote(string) {
  return `"${string.replace(/\\/g, "\\\\").replace(/"/g, '\\"')}"`;
}
function serializeArray(value, stack) {
  const result = new Array(value.length);
  for (let i = 0; i < value.length; i++) {
    const member = value[i];
    const type = typeof member;
    if (member === null || member === void 0) {
      result[i] = "NULL";
    } else if (type === "boolean") {
      result[i] = member ? "t" : "f";
    } else if (type === "bigint" || type === "number") {
      result[i] = `${member}`;
    } else if (Array.isArray(member)) {
      const cached = serializationCache.get(member);
      if (cached) {
        result[i] = cached;
      } else {
        if (stack.has(member))
          throw new TypeError("Circularity detected serializing");
        stack.add(member);
        result[i] = serializeArray(member, stack);
        serializationCache.set(member, result[i]);
        stack.delete(member);
      }
    } else if (ArrayBuffer.isView(member)) {
      result[i] = `"\\${(0, import_bytea.serializeByteA)(member)}"`;
    } else {
      result[i] = quote(serializeValue(member, stack));
    }
  }
  return `{${result.join(",")}}`;
}
function serializeValue(value, stack) {
  if (value === null)
    throw new TypeError('Can not serialize "null"');
  switch (typeof value) {
    case "string":
      return value;
    case "boolean":
      return value ? "t" : "f";
    case "bigint":
    case "number":
      return value.toString();
    case "object":
      break;
    case "function":
    case "symbol":
    case "undefined":
    default:
      throw new TypeError(`Can not serialize "${typeof value}"`);
  }
  const cached = serializationCache.get(value);
  if (cached !== void 0)
    return cached;
  if (stack.has(value))
    throw new TypeError("Circularity detected serializing");
  stack.add(value);
  const subserialize = (v) => serializeValue(v, stack);
  let string;
  if (isPGSerializable(value)) {
    string = value.toPostgres(subserialize);
  } else if (ArrayBuffer.isView(value)) {
    string = (0, import_bytea.serializeByteA)(value);
  } else if (Array.isArray(value)) {
    string = serializeArray(value, stack);
  } else if (value instanceof Date) {
    string = (0, import_date.serializeDateUTC)(value);
  } else {
    string = JSON.stringify(value);
  }
  serializationCache.set(value, string);
  stack.delete(value);
  return string;
}
function isPGSerializable(value) {
  return value && typeof value["toPostgres"] === "function";
}
var serialize = (value) => serializeValue(value, /* @__PURE__ */ new WeakSet());
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  serialize,
  serializeByteA,
  serializeDateUTC
});
//# sourceMappingURL=serializers.cjs.map
