/**
 * Defines an object that can be serialized to a _string_ comprehensible by
 * PostgreSQL.
 *
 * The `serialize` parameter is a serialization function which can be used
 * to serialize _members_ of the {@link PGSerializable} itself (e.g. boundaries
 * of a {@link PGRange}, members of an _array_, ...).
 */
export interface PGSerializable {
    toPostgres(serialize: PGSerialize): string;
}
/** An interface describing our {@link serialize} function. */
export interface PGSerialize {
    (value?: null | undefined): never;
    (value: any): string;
}
/** Serialize a value to _string_ comprehensible by PostgreSQL. */
export declare const serialize: PGSerialize;
export { serializeByteA } from './serializers/bytea';
export { serializeDateUTC } from './serializers/date';
